Commands (CLI)
==============

This document covers the ``linchpin`` Command Line Interface (CLI) in detail. Each page contains a description and explanation for each component. For an overview, see :ref:`gs_running`.

.. toctree::
   :maxdepth: 1

   linchpin_init
   linchpin_up
   linchpin_destroy
   linchpin_journal
   linchpin_fetch
   linchpin_validate



